@@ -4,11 +4,8 @@
 name = 'plain_db'
 import os
 
-def getFile(fn, result = None, isIntValue=True):
-	if result == None:
-		# need this, otherwise result will be 
-		# persistent between different loads
-		result = {} 
+def getFile(fn, isIntValue=True):
+	result = {}
 	if not os.path.exists(fn):
 		return result
 	with open(fn) as f:
@@ -26,19 +23,12 @@ def getFile(fn, result = None, isIntValue=True):
 	return result
 
 class DB(object):
-	def __init__(self, name, isIntValue=True, default = None,
-			delayLoad = False): 
+	def __init__(self, name, isIntValue=True, default = None): 
 		self.fn = 'db/' + name
 		self.isIntValue = isIntValue
-		if not delayLoad:
-			self.items = getFile(self.fn, isIntValue=isIntValue)
-		else:
-			self.items = {}
+		self.items = getFile(self.fn, isIntValue=isIntValue)
 		self.defaultValue = default
 
-	def load(self):
-		getFile(self.fn, isIntValue=self.isIntValue, result=self.items)
-
 	def update(self, key, value):
 		if key not in self.items:
 			self.items[key] = value
@@ -106,9 +96,9 @@ def loadKeyOnlyDB(fn):
 
 class LargeDB(object):
 	def __init__(self, name, isIntValue=False, 
-			default=None, delayLoad=False):
+			default=None):
 		self._db = DB(name, isIntValue=isIntValue, 
-			default = default, delayLoad=delayLoad)
+			default = default)
 
 	def load(self):
 		self._db.load()
@@ -133,9 +123,8 @@ class LargeDB(object):
 	def getFn(self):
 		return self._db.fn
 
-def loadLargeDB(fn, isIntValue=False, default=None, delayLoad=False):
-	return LargeDB(fn, isIntValue=isIntValue, default = default,
-		delayLoad = delayLoad)
+def loadLargeDB(fn, isIntValue=False, default=None):
+	return LargeDB(fn, isIntValue=isIntValue, default = default)
 
 def cleanupLargeDB(fn):
 	f1 = loadLargeDB(fn)
